@@ -134,7 +134,7 @@ where
                 .map_err(Error::io)
         }
     }
-    #[inline(never)]
+    #[inline]
     fn serialize_f64(self, value: f64) -> Result<()> {
         if unlikely!(value.is_infinite() || value.is_nan()) {
             self.serialize_unit()
@@ -604,7 +604,7 @@ where
     unsafe {
         reserve_str!(writer, value);
 
-        let written = format_escaped_str_impl_generic_128(
+        let written = format_escaped_str_impl_sse2_128(
             writer.as_mut_buffer_ptr(),
             value.as_bytes().as_ptr(),
             value.len(),
@@ -631,7 +631,7 @@ where
             );
             writer.set_written(written);
         } else {
-            let written = format_escaped_str_impl_generic_128(
+            let written = format_escaped_str_impl_sse2_128(
                 writer.as_mut_buffer_ptr(),
                 value.as_bytes().as_ptr(),
                 value.len(),
@@ -641,7 +641,7 @@ where
     }
 }
 
-#[cfg(not(feature = "unstable-simd"))]
+#[cfg(all(not(feature = "unstable-simd"), not(target_arch = "x86_64")))]
 #[inline(always)]
 fn format_escaped_str<W>(writer: &mut W, value: &str)
 where
@@ -659,6 +659,25 @@ where
     }
 }
 
+#[cfg(all(not(feature = "unstable-simd"), target_arch = "x86_64"))]
+#[inline(always)]
+fn format_escaped_str<W>(writer: &mut W, value: &str)
+where
+    W: ?Sized + io::Write + WriteExt,
+{
+    unsafe {
+        reserve_str!(writer, value);
+
+        let written = format_escaped_str_impl_sse2_128(
+            writer.as_mut_buffer_ptr(),
+            value.as_bytes().as_ptr(),
+            value.len(),
+        );
+
+        writer.set_written(written);
+    }
+}
+
 #[inline]
 pub fn to_writer<W, T>(writer: W, value: &T) -> Result<()>
 where
